<?php
// define class
// to manually implement file locking
class fileLock {
	// define properties
	private $file;

	// constructor
	public function __construct($file) {
		$this->file = $file;
		$this->lock();
	}

	// method to create lock file
	public function lock() {
		// clear file cache
		clearstatcache();

		// check if a lock file already exists
		// if not, create one
		// if it does, retry after a few seconds
		echo "Attempting to lock file...\n";
		if (!file_exists($this->file . ".lock")) {
			touch ($this->file . ".lock", time()) or die("ERROR: Could not create lock file!\n");
			echo "File locked!\n";
		} else {
			echo "Lock exists, retrying after 2 seconds...\n";
			sleep(2);
			$this->lock();	
		}	
	}
	
	// method to write data to locked file
	public function write($data) {
			// try to write to file
			// display error and return if unsuccessful
			echo "Attempting file write...\n";
			if (!$fp = fopen($this->file, "a+")) {
				echo "ERROR: Cannot open file for writing!\n";
				return false;
			}
			if (!fwrite($fp, $data)) {
				echo "ERROR: Cannot write to file!\n";
				return false;
			} 
			if (!fclose($fp)) { 
				echo "ERROR: Cannot close file!\n";
			}
			echo "Data written to file!\n";
	}
	
	// destructor
	public function __destruct() {
		$this->unlock();
	}

	// method to remove lock file
	public function unlock() {
		// delete lock file
		echo "Unlocking file...\n";
		unlink ($this->file . ".lock") or die("ERROR: Cannot remove lock file!");
		echo "File unlocked!\n";
	}
}

// create object
// set file lock
$fl = new fileLock("/tmp/data.txt");

// write data to file
$fl->write("I can see you!");

// remove lock
unset($fl);
?>
