<?php
// turn off error messages
error_reporting(E_NONE);

// subclass the Exception class 
class LenException extends Exception {} 
class NameException extends Exception {} 
class UniqueException extends Exception {} 

// function to test a password
function changePassword($str) {
    // password too short
    // trigger an exception
    if(strlen($str) < 8)  {
        throw new LenException($str);
    }

    // password contains user name
    // trigger an exception
    if (isset($_SESSION['uname'])) {
        if (ereg($_SESSION['uname'], $str)) {
            throw new NameException($str);
        }
    }

    // password contains insufficient unique characters
    // trigger an exception
    if(strlen(count_chars($str, 3)) < 6) {
        throw new UniqueException($str);
    }
    
    echo "Your password was successfully changed ($str).";
}

// try this code
try {
    changePassword("h3llo");     // too short
    changePassword("g5gg3gh3");  // not enough uniques
    changePassword("h46wkd3g8"); // acceptable
    // catch errors if any
} catch (LenException $e) {
    print "The password supplied is too short (" . $e->getMessage() . "). Please provide a password containing at least 8 characters.";
} catch (NameException $e) {
    print "The password supplied is based on your username. (" . $e->getMessage() . "). Please provide a different password.";
} catch (UniqueException $e) {
    print "The password supplied does not contain a sufficient number of unique characters (" . $e->getMessage() . ").  Please provide a password containing at least 6 unique characters";
} catch (Exception $e) {
    echo "Exception! \n";
    echo "Error message: " . $e->getMessage() . " \n";
    echo "Error code: " . $e->getCode() . " \n";
    echo "File and line: " . $e->getFile() . "(" . $e->getLine() . ") \n";
    echo "Trace: " . $e->getTraceAsString() . " \n";
}
?>
