<?php
// custom exception handler
function exh($e) {
    // when an exception is caught
    // erase all previously-generated output
    ob_end_clean() or die("Cannot erase output buffer");

    // construct the error string 
    $timestamp = date("d-m-Y H:i:s", mktime()); 
    $errorStr  = "$timestamp ". get_class($e) . ": ";
    $errorStr .= $e->getMessage() . " in ";
    $errorStr .= $e->getFile() . "(line " . $e->getLine() . ")\n";
    
    // log the error to a file
    error_log($errorStr, 3, "error_log") or die("Cannot write to error log");
    
    // display error message as output
    echo "This is the custom exception handler. Something went wrong, which is why you're meeting me. Give the webmaster a call and ask him to check the error log for [$timestamp]";
}

// turn off error reporting
error_reporting(E_NONE);

// start output buffering
ob_start();

// set a custom handler for all exceptions
set_exception_handler("exh");

// sub-class exception
class LoadException extends Exception { }
class DBException extends Exception { }

// load SQLite extenstion
if (!extension_loaded("sqlite")) {
    if(!dl("php_sqlite.dll")) {
        throw new LoadException("Cannot load extension file: php_sqlite.dll");
    }
}

// open connection
if (!$handle = sqlite_open('products.db')) {
    throw new DBException("Cannot connect to SQLite database");
}

// create and execute INSERT query
$sql = "INSERT INTO products (id, name) VALUES ('5', 'pears')";
if (!sqlite_query($handle, $sql)) {
    throw new DBException("Cannot execute SQL query [$sql] " . sqlite_error_string(sqlite_last_error($handle)));
}

// close connection
sqlite_close($handle);
echo "SQLite transaction successfully completed";
?>
